#ifndef H_SIGNALS
#define H_SIGNALS

#include <sys/time.h>
#include <sys/types.h>
#include <unistd.h>

void rl_siginit();
void rls_block();
void rls_unblock();

#define RL_MAX(a,b) ((a) > (b) ? (a) : (b))

extern volatile int rls_need_parse;
extern volatile struct pidtab *rls_reaped;

#endif /* !H_SIGNALS */
